==> cli-3.6.4-sources.jar: com/xebialabs/deployit/cli/CliOptions.java <==
package com.xebialabs.deployit.cli;

import org.kohsuke.args4j.Argument;
import org.kohsuke.args4j.CmdLineException;
import org.kohsuke.args4j.CmdLineParser;
import org.kohsuke.args4j.Option;
import org.kohsuke.args4j.spi.StopOptionHandler;

import java.io.File;
import java.util.List;

import static com.google.common.collect.Lists.newArrayList;
import static java.lang.String.format;

public class CliOptions {
	
	static final int DEFAULT_DEPLOYIT_SERVER_PORT = 4516;
	static final int DEFAULT_DEPLOYIT_SERVER_SECURE_PORT = 4517;
	static final String DEFAULT_DEPLOYIT_SERVER_HOST = "127.0.0.1";
	static final String EXTENSION_DIR = "ext";
	
	@Option(name = "-secure", usage = "Use https to connect to the Deployit server", required = false)
	private boolean secured = false;

	@Option(name = "-expose-proxies", required = false)
	private boolean exposeProxies = false;

	@Option(name = "-host", usage = "Connect to a specified host, defaults to " + DEFAULT_DEPLOYIT_SERVER_HOST, required = false)
	private String host = DEFAULT_DEPLOYIT_SERVER_HOST;

	@Option(name = "-port", usage = "Connect to a specified port, defaults to " + DEFAULT_DEPLOYIT_SERVER_PORT, required = false)
	private int port = -1;

	@Option(name = "-context", usage = "Context url Deployit is running at, defaults to /deployit", required = false)
	private String context = "deployit";

	@Option(name = "-f", usage = "Execute a specified python source file", required = false, aliases = { "-source" })
	private String sourceFileName = null;

	@Option(name = "-q", aliases = "-quiet", usage = "Suppresses the welcome banner", required = false)
	private boolean quiet = false;

	@Option(name = "-username", usage = "Connect as the specified user", required = false)
	private String username;

	@Option(name = "-password", usage = "Connect with the specified password", required = false)
	private String password;

	@Option(name = "-configuration", usage = "Specify the location of the configuration file", required = false)
	private String configLocation = "conf";

    @Argument
	@Option(name = "--", handler = StopOptionHandler.class)
    private List<String> scriptArgs = newArrayList();

	private static final String DEPLOYIT_CONF_FILE_NAME = "deployit.conf";

	public void setHost(String host) {
		this.host = host;
	}

	public String getHost() {
		return host;
	}

	public void setPort(int port) {
		this.port = port;
	}

	public int getPort() {
		return port == -1 ? (secured ? DEFAULT_DEPLOYIT_SERVER_SECURE_PORT : DEFAULT_DEPLOYIT_SERVER_PORT) : port;
	}

	public void setSourceFileName(String sourceFileName) {
		this.sourceFileName = sourceFileName;
	}

	public String getSourceFileName() {
		return sourceFileName;
	}

	public boolean interpretSourceFile() {
		return (this.sourceFileName != null);
	}

	public boolean isUsernameOnCommandline() {
		return this.username != null;
	}

	public boolean isPasswordOnCommandline() {
		return this.password != null;
	}

	public boolean isExposeProxies() {
		return exposeProxies;
	}

	public void setExposeProxies(boolean exposeProxies) {
		this.exposeProxies = exposeProxies;
	}

	public String getUsername() {
		return username;
	}

	public void setUsername(final String username) {
		this.username = username;
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(final String password) {
		this.password = password;
	}

	public String getConfigLocation() {
		return configLocation;
	}

	public void setConfigLocation(final String configLocation) {
		this.configLocation = configLocation;
	}

	public File getConfigurationFile() {
		return new File(configLocation, DEPLOYIT_CONF_FILE_NAME);
	}

	public boolean isSecured() {
		return secured;
	}

	public void setSecured(boolean secured) {
		this.secured = secured;
	}

	public String getUrl() {
		return format("http%s://%s:%d/%s", secured ? "s" : "", host, getPort(), getContext());
	}

    public List<String> getScriptArgs() {
        return scriptArgs;
    }

    public void setScriptArgs(List<String> scriptArgs) {
        this.scriptArgs = scriptArgs;
    }

	public String getContext() {
		return context;
	}

	public void setContext(String context) {
		this.context = context;
	}

	public boolean isQuiet() {
		return quiet;
	}

	public void setQuiet(boolean quiet) {
		this.quiet = quiet;
	}

	static CliOptions parse(String... args) {
		CliOptions options = new CliOptions();
		final CmdLineParser parser = new CmdLineParser(options);
		try {
			parser.parseArgument(args);
		} catch (CmdLineException e) {			
			System.err.println(e.getMessage());			
			System.err.println("Usage: ./cli." + (System.getProperty("os.name").matches("(?i).*windows.*") ? "cmd" : "sh") + " [options] [[--] arguments]\n");
			System.err.println("Options:\n");
			parser.printUsage(System.err);
			return null;
		}
		return options;
	}
}

==> cli-3.7.2-sources.jar: com/xebialabs/deployit/cli/CliOptions.java <==
package com.xebialabs.deployit.cli;

import org.kohsuke.args4j.Argument;
import org.kohsuke.args4j.CmdLineException;
import org.kohsuke.args4j.CmdLineParser;
import org.kohsuke.args4j.Option;
import org.kohsuke.args4j.spi.StopOptionHandler;

import java.io.File;
import java.io.PrintStream;
import java.util.List;

import static com.google.common.collect.Lists.newArrayList;
import static java.lang.String.format;

public class CliOptions {
	
	static final int DEFAULT_DEPLOYIT_SERVER_PORT = 4516;
	static final int DEFAULT_DEPLOYIT_SERVER_SECURE_PORT = 4517;
	static final String DEFAULT_DEPLOYIT_SERVER_HOST = "127.0.0.1";
	static final String EXTENSION_DIR = "ext";
	
	@Option(name = "-secure", usage = "Use https to connect to the Deployit server", required = false)
	private boolean secured = false;

	@Option(name = "-expose-proxies", required = false)
	private boolean exposeProxies = false;

	@Option(name = "-host", usage = "Connect to a specified host, defaults to " + DEFAULT_DEPLOYIT_SERVER_HOST, required = false)
	private String host = DEFAULT_DEPLOYIT_SERVER_HOST;

	@Option(name = "-port", usage = "Connect to a specified port, defaults to " + DEFAULT_DEPLOYIT_SERVER_PORT, required = false)
	private int port = -1;

	@Option(name = "-context", usage = "Context url Deployit is running at, defaults to ''", required = false)
	private String context = "";

	@Option(name = "-f", usage = "Execute a specified python source file", required = false, aliases = { "-source" })
	private String sourceFileName = null;

	@Option(name = "-q", aliases = "-quiet", usage = "Suppresses the welcome banner", required = false)
	private boolean quiet = false;

	@Option(name = "-username", usage = "Connect as the specified user", required = false)
	private String username;

	@Option(name = "-password", usage = "Connect with the specified password", required = false)
	private String password;

	@Option(name = "-configuration", usage = "Specify the location of the configuration file", required = false)
	private String configLocation = "conf";

	@Option(name = "-help", usage = "Prints this usage message", required = false)
	private boolean printUsage = false;
	
    @Argument
	@Option(name = "--", handler = StopOptionHandler.class)
    private List<String> scriptArgs = newArrayList();

	private static final String DEPLOYIT_CONF_FILE_NAME = "deployit.conf";

	public void setHost(String host) {
		this.host = host;
	}

	public String getHost() {
		return host;
	}

	public void setPort(int port) {
		this.port = port;
	}

	public int getPort() {
		return port == -1 ? (secured ? DEFAULT_DEPLOYIT_SERVER_SECURE_PORT : DEFAULT_DEPLOYIT_SERVER_PORT) : port;
	}

	public void setSourceFileName(String sourceFileName) {
		this.sourceFileName = sourceFileName;
	}

	public String getSourceFileName() {
		return sourceFileName;
	}

	public boolean interpretSourceFile() {
		return (this.sourceFileName != null);
	}

	public boolean isUsernameOnCommandline() {
		return this.username != null;
	}

	public boolean isPasswordOnCommandline() {
		return this.password != null;
	}

	public boolean isExposeProxies() {
		return exposeProxies;
	}

	public void setExposeProxies(boolean exposeProxies) {
		this.exposeProxies = exposeProxies;
	}

	public String getUsername() {
		return username;
	}

	public void setUsername(final String username) {
		this.username = username;
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(final String password) {
		this.password = password;
	}

	public String getConfigLocation() {
		return configLocation;
	}

	public void setConfigLocation(final String configLocation) {
		this.configLocation = configLocation;
	}

	public File getConfigurationFile() {
		return new File(configLocation, DEPLOYIT_CONF_FILE_NAME);
	}

	public boolean isSecured() {
		return secured;
	}

	public void setSecured(boolean secured) {
		this.secured = secured;
	}

	public String getUrl() {
		return format("http%s://%s:%d/%s", secured ? "s" : "", host, getPort(), getContext());
	}

    public List<String> getScriptArgs() {
        return scriptArgs;
    }

    public void setScriptArgs(List<String> scriptArgs) {
        this.scriptArgs = scriptArgs;
    }

	public String getContext() {
		if (!context.endsWith("deployit")) {
			context = context + "/deployit";
		}
		if (context.startsWith("/")) {
			context = context.substring(1);
		}
		return context;
	}

	public void setContext(String context) {
		this.context = context;
	}

	public boolean isPrintUsage() {
		return printUsage;
	}

	public void setPrintUsage(boolean printUsage) {
		this.printUsage = printUsage;
	}

	public boolean isQuiet() {
		return quiet;
	}

	public void setQuiet(boolean quiet) {
		this.quiet = quiet;
	}

	static CliOptions parse(String... args) {
		CliOptions options = new CliOptions();
		final CmdLineParser parser = new CmdLineParser(options);
		try {
			parser.parseArgument(args);

			if (options.isPrintUsage()) {
				printUsage(parser, System.err);
				return null;
			}
		} catch (CmdLineException e) {			
			System.err.println(e.getMessage());
			printUsage(parser, System.out);
			return null;
		}

		return options;
	}

	private static void printUsage(CmdLineParser parser, PrintStream stream) {
		stream.println("Usage: ./cli." + (System.getProperty("os.name").matches("(?i).*windows.*") ? "cmd" : "sh") + " [options] [[--] arguments]\n");
		stream.println("Options:\n");
		parser.printUsage(stream);
	}
}
